﻿using CreateLearnerExample.Models;
using CreateLearnerExample.Services.V1;
using CreateLearnerExample.Services.V2;
using System;
using System.Net.Http;
using CreateLearnerExample.Models.Enums;

namespace CreateLearnerExample
{
    public class Program
    {
        private static HttpClient client = new HttpClient();

        /*
         * Auto generated docs can be found at 
         * https://wsapi.onefile.co.uk/Help
         *
         */

        // Host URL for BETA
        private const string BETAHOST = "https://wsapibeta.onefile.co.uk";
        // Host URL for LIVE
        public const string LIVEHOST = "https://wsapi.onefile.co.uk";

        // Set the environment you want to point to (BETA as default)
        public const string HOST = BETAHOST;

        // Replace [YOUR GUID HERE] with your given API Token
        private const String APITOKEN = "Your customer token here (GUID)";

        // Replace 0 with the organisation id to create the learner in
        private const int ORGANISATIONID = 0;

        public static void Main(string[] args)
        {
            if (!Guid.TryParse(APITOKEN, out Guid customerToken))
            {
                throw new ArgumentException("Invalid APITOKEN! Please check the value and amend as required");
            }

            V2Endpoints(customerToken);

            client.Dispose();

            Console.ReadKey();
        }

        public static async void V1Endpoints(Guid customerToken)
        {
            // Authenticate
            var authService = new AuthenticationService(client);
            Guid sessionId = await authService.Authenticate(customerToken);

            var learnerService = new LearnerService(client);

            // Get Learners
            var learners = await learnerService.GetLearners(sessionId, ORGANISATIONID);
            Console.WriteLine("Number of learners retrieved: " + learners.Count);

            // Create Learner
            User learnerData = new User
            {
                FirstName = "Learner",
                LastName = "Test",
                OrganisationID = ORGANISATIONID
            };

            int newLearnerId = await learnerService.CreateLearner(sessionId, learnerData);
            Console.WriteLine("New LearnerID - " + newLearnerId);
        }

        public static async void V2Endpoints(Guid customerToken)
        {
            // Authenticate
            AuthenticationServiceV2 authServiceV2 = new AuthenticationServiceV2(client);
            string authToken = authServiceV2.Authenticate(customerToken);

            // User
            UserServiceV2 userServiceV2 = new UserServiceV2(client);

            // Creating a user
            var newUser = await userServiceV2.CreateUser(authToken, new User
            {
                OrganisationID = ORGANISATIONID,
                PlacementID = 1,
                DefaultAssessorID = 2,
                ClassroomID = 1,
                Email = "test@email.com",
                FirstName = "firstname",
                LastName = "lastname",
                Role = AccountRoles.Learner
            });
        }
    }
}
